@@ -126,6 +126,7 @@ def MessageListenerMethod(
         def innerResourceInstanceMethod(*args, **kwargs):
             args = wrapperManager.addResourceInFrontOfArgs(args)
             messageAsJson = FlaskUtil.safellyGetRequestBody()
+            completeResponse = None
             if not wrapperManager.muteLogs:
                 log.info(wrapperManager.resourceInstanceMethod, f'''{LogConstant.LISTENER_SPACE}{FlaskUtil.safellyGetVerb()}{c.SPACE_DASH_SPACE}{FlaskUtil.safellyGetUrl()}''')
                 try:
@@ -172,7 +173,7 @@ def MessageListenerMethod(
                     wrapperManager.resourceInstance.queueManager.runInAThread(resolveListenerCall, *listennerArgs)
                 else:
                     completeResponse = resolveListenerCall(*listennerArgs)
-                if HttpStatus.BAD_REQUEST < completeResponse[-1]:
+                if ObjectHelper.isEmpty(completeResponse) or HttpStatus.BAD_REQUEST < completeResponse[-1]:
                     completeResponse = [
                         MessageDto.MessageCreationResponseDto(
                             key = messageAsJson.get(MessageConstant.MESSAGE_KEY_KEY),
@@ -289,7 +290,7 @@ def resolveListenerCall(
     except Exception as exception:
         log.failure(resolveListenerCall, f'Failure while parsing complete response: {completeResponse}. Returning simplified version of it', exception, muteStackTrace=True)
         completeResponse = getCompleteResponseByException(
-            Exception(f'Not possible to handle complete response. Cause: {str(exception)}'),
+            Exception(f'Not possible to handle complete response{c.DOT_SPACE_CAUSE}{str(exception)}'),
             wrapperManager.resourceInstance,
             wrapperManager.resourceInstanceMethod,
             resourceInstanceMethodMuteStacktraceOnBusinessRuleException
